Please provide as much as possible information to reproduce the issue.

# Basic information
  - Type of the CPU.
  - Type of the GPU (if you try to miner with the GPU).

# Compile issues
  - Which OS do you use?
  ```
  add **all** commands you used and the **full** compile output here
  ```
  ```
  run `cmake -LA .` in the build folder and add the output here
  ```

# Issue with the execution
  - Do you compiled the miner by our own?
  ```
  run `./xmr-stak --version-long` and add the output here
  ```

# AMD OpenCl issue

  ```
  run `clinfo` and add the output here
  ```

# Stability issue
  - Is the CPU or GPU overclocked?
  - Is the Main memory of the CPU or GPU undervolted?
